@@ -6,4 +6,7 @@ knitr::opts_chunk$set(
 
 ## ----setup--------------------------------------------------------------------
 library(fidap)
+client <- fidap_client(api_key='xxxxxxx', source='bq')
+df <- client$sql('select * from table_name')
+print(df)
 
